==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/eu.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Zerbitzaritik zerbitzarirako elkarbanaketa ez dago gaituta zerbitzari honetan",
    "The mountpoint name contains invalid characters." : "Montatze puntuaren izenak baliogabeko karaktereak ditu.",
    "Invalid or untrusted SSL certificate" : "SSL ziurtagiri baliogabea edo fidagaitza",
    "Storage not valid" : "Biltegi bliogabea",
    "Couldn't add remote share" : "Ezin izan da hurruneko elkarbanaketa gehitu",
    "Shared with you" : "Zurekin elkarbanatuta",
    "Shared with others" : "Beste batzuekin elkarbanatuta",
    "Shared by link" : "Lotura bidez elkarbanatuta",
    "Nothing shared with you yet" : "Oraindik ez da ezer partekatu zurekin",
    "Files and folders others share with you will show up here" : "Zurekin partekatutako fitxategi eta karpetak hemen agertuko dira",
    "Nothing shared yet" : "Oraindik ez da ezer partekatu",
    "Files and folders you share will show up here" : "Partekatzen dituzun fitxategi eta karpetak hemen agertuko dira",
    "No shared links" : "Ez dago partekatutako loturarik",
    "Files and folders you share by link will show up here" : "Lotura bidez partekatzen dituzun fitxategi eta karpetak hemen agertuko dira",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Nahi duzu gehitzea  {name}  urrutiko partekatzea honengandik  {owner}@{remote}?",
    "Remote share" : "Urrutiko parte hartzea",
    "Remote share password" : "Urrutiko parte hartzeen pasahitza",
    "Cancel" : "Ezeztatu",
    "Add remote share" : "Gehitu urrutiko parte hartzea",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ez da ownClouden instalaziorik (7 edo haundiago) aurkitu {remote}n",
    "Invalid ownCloud url" : "ownCloud url baliogabea",
    "Share" : "Partekatu",
    "Shared by" : "Honek elkarbanatuta",
    "A file or folder has been <strong>shared</strong>" : "Fitxategia edo karpeta <strong>konpartitu</strong> da",
    "A file or folder was shared from <strong>another server</strong>" : "Fitxategia edo karpeta konpartitu da <strong>beste zerbitzari batetatik</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publikoki partekatutako fitxategi edo karpeta bat <strong>deskargatu da</strong>",
    "Public shared folder %1$s was downloaded" : "Publikoki partekatutako %1$s karpeta deskargatu da",
    "Public shared file %1$s was downloaded" : "Publikoki partekatutako %1$s fitxategia deskargatu da",
    "You shared %1$s with %2$s" : "Zuk %1$s elkarbanatu duzu %2$srekin",
    "You shared %1$s with group %2$s" : "Zuk %1$s elkarbanatu duzu %2$s taldearekin",
    "%2$s shared %1$s with you" : "%2$sk zurekin %1$s elkarbanatu du",
    "You shared %1$s via link" : "Konpartitu duzu %1$s esteka baten bidez",
    "Shares" : "Partekatuak",
    "This share is password-protected" : "Elkarbanatutako hau pasahitzarekin babestuta dago",
    "The password is wrong. Try again." : "Pasahitza ez da egokia. Saiatu berriro.",
    "Password" : "Pasahitza",
    "No entries found in this folder" : "Karpeta honetan ez da sarreraik aurkitu",
    "Name" : "Izena",
    "Share time" : "Elkarbanatze unea",
    "Sorry, this link doesn’t seem to work anymore." : "Barkatu, lotura ez dirudi eskuragarria dagoenik.",
    "Reasons might be:" : "Arrazoiak hurrengoak litezke:",
    "the item was removed" : "fitxategia ezbatua izan da",
    "the link expired" : "lotura iraungi da",
    "sharing is disabled" : "elkarbanatzea ez dago gaituta",
    "For more info, please ask the person who sent this link." : "Informazio gehiagorako, mesedez eskatu lotura hau bidali zuen pertsonari",
    "Add to your ownCloud" : "Gehitu zure ownCloud-era",
    "Download" : "Deskargatu",
    "Download %s" : "Deskargatu %s",
    "Direct link" : "Lotura zuzena",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Allow users on this server to send shares to other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzariekin partekatzera",
    "Allow users on this server to receive shares from other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzarietatik partekatutakoak jasotzen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/eu.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Zerbitzaritik zerbitzarirako elkarbanaketa ez dago gaituta zerbitzari honetan",
    "The mountpoint name contains invalid characters." : "Montatze puntuaren izenak baliogabeko karaktereak ditu.",
    "Invalid or untrusted SSL certificate" : "SSL ziurtagiri baliogabea edo fidagaitza",
    "Storage not valid" : "Biltegi bliogabea",
    "Couldn't add remote share" : "Ezin izan da hurruneko elkarbanaketa gehitu",
    "Shared with you" : "Zurekin elkarbanatuta",
    "Shared with others" : "Beste batzuekin elkarbanatuta",
    "Shared by link" : "Lotura bidez elkarbanatuta",
    "Nothing shared with you yet" : "Oraindik ez da ezer partekatu zurekin",
    "Files and folders others share with you will show up here" : "Zurekin partekatutako fitxategi eta karpetak hemen agertuko dira",
    "Nothing shared yet" : "Oraindik ez da ezer partekatu",
    "Files and folders you share will show up here" : "Partekatzen dituzun fitxategi eta karpetak hemen agertuko dira",
    "No shared links" : "Ez dago partekatutako loturarik",
    "Files and folders you share by link will show up here" : "Lotura bidez partekatzen dituzun fitxategi eta karpetak hemen agertuko dira",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Nahi duzu gehitzea  {name}  urrutiko partekatzea honengandik  {owner}@{remote}?",
    "Remote share" : "Urrutiko parte hartzea",
    "Remote share password" : "Urrutiko parte hartzeen pasahitza",
    "Cancel" : "Ezeztatu",
    "Add remote share" : "Gehitu urrutiko parte hartzea",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ez da ownClouden instalaziorik (7 edo haundiago) aurkitu {remote}n",
    "Invalid ownCloud url" : "ownCloud url baliogabea",
    "Shared by" : "Honek elkarbanatuta",
    "Sharing" : "Partekatzea",
    "A file or folder has been <strong>shared</strong>" : "Fitxategia edo karpeta <strong>konpartitu</strong> da",
    "A file or folder was shared from <strong>another server</strong>" : "Fitxategia edo karpeta konpartitu da <strong>beste zerbitzari batetatik</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publikoki partekatutako fitxategi edo karpeta bat <strong>deskargatu da</strong>",
    "Public shared folder %1$s was downloaded" : "Publikoki partekatutako %1$s karpeta deskargatu da",
    "Public shared file %1$s was downloaded" : "Publikoki partekatutako %1$s fitxategia deskargatu da",
    "You shared %1$s with %2$s" : "Zuk %1$s elkarbanatu duzu %2$srekin",
    "You shared %1$s with group %2$s" : "Zuk %1$s elkarbanatu duzu %2$s taldearekin",
    "You shared %1$s via link" : "Konpartitu duzu %1$s esteka baten bidez",
    "%2$s shared %1$s with you" : "%2$sk zurekin %1$s elkarbanatu du",
    "Shares" : "Partekatuak",
    "This share is password-protected" : "Elkarbanatutako hau pasahitzarekin babestuta dago",
    "The password is wrong. Try again." : "Pasahitza ez da egokia. Saiatu berriro.",
    "Password" : "Pasahitza",
    "No entries found in this folder" : "Karpeta honetan ez da sarreraik aurkitu",
    "Name" : "Izena",
    "Share time" : "Elkarbanatze unea",
    "Sorry, this link doesn’t seem to work anymore." : "Barkatu, lotura ez dirudi eskuragarria dagoenik.",
    "Reasons might be:" : "Arrazoiak hurrengoak litezke:",
    "the item was removed" : "fitxategia ezbatua izan da",
    "the link expired" : "lotura iraungi da",
    "sharing is disabled" : "elkarbanatzea ez dago gaituta",
    "For more info, please ask the person who sent this link." : "Informazio gehiagorako, mesedez eskatu lotura hau bidali zuen pertsonari",
    "Add to your ownCloud" : "Gehitu zure ownCloud-era",
    "Download" : "Deskargatu",
    "Download %s" : "Deskargatu %s",
    "Direct link" : "Lotura zuzena",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Allow users on this server to send shares to other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzariekin partekatzera",
    "Allow users on this server to receive shares from other servers" : "Baimendu zerbitzari honetako erabiltzaileak beste zerbitzarietatik partekatutakoak jasotzen",
    "Public shared file %1$s was downloaded" : "Publikoki partekatutako %1$s fitxategia deskargatu da",
    "Public shared folder %1$s was downloaded" : "Publikoki partekatutako %1$s karpeta deskargatu da"
},
"nplurals=2; plural=(n != 1);");
